package com.bonus.canteen.core.health.service;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthPersonInfo;

/**
 * 人员健康情况Service接口
 *
 * @author xsheng
 * @date 2025-05-25
 */
public interface IHealthPersonInfoService {
    /**
     * 查询人员健康情况
     *
     * @param id 人员健康情况主键
     * @return 人员健康情况
     */
    public HealthPersonInfo selectHealthPersonInfoById(Long id);

    /**
     * 查询人员健康情况列表
     *
     * @param healthPersonInfo 人员健康情况
     * @return 人员健康情况集合
     */
    public List<HealthPersonInfo> selectHealthPersonInfoList(HealthPersonInfo healthPersonInfo);

    /**
     * 新增人员健康情况
     *
     * @param healthPersonInfo 人员健康情况
     * @return 结果
     */
    public int insertHealthPersonInfo(HealthPersonInfo healthPersonInfo);

    /**
     * 修改人员健康情况
     *
     * @param healthPersonInfo 人员健康情况
     * @return 结果
     */
    public int updateHealthPersonInfo(HealthPersonInfo healthPersonInfo);

    /**
     * 批量删除人员健康情况
     *
     * @param ids 需要删除的人员健康情况主键集合
     * @return 结果
     */
    public int deleteHealthPersonInfoByIds(Long[] ids);

    /**
     * 删除人员健康情况信息
     *
     * @param id 人员健康情况主键
     * @return 结果
     */
    public int deleteHealthPersonInfoById(HealthPersonInfo content);
}
