package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonInfo;
import com.bonus.canteen.core.health.service.IHealthPersonInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员健康情况Controller
 *
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "人员健康情况接口")
@RestController
@RequestMapping("/health_person_info")
public class HealthPersonInfoController extends BaseController {
    @Autowired
    private IHealthPersonInfoService healthPersonInfoService;

    /**
     * 查询人员健康情况列表
     */
    @ApiOperation(value = "查询人员健康情况列表")
    //@RequiresPermissions("health:info:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonInfo healthPersonInfo) {
        startPage();
        System.out.println(healthPersonInfo.getPlaceIds());
        List<HealthPersonInfo> list = healthPersonInfoService.selectHealthPersonInfoList(healthPersonInfo);
        return getDataTable(list);
    }

    /**
     * 导出人员健康情况列表
     */
    @ApiOperation(value = "导出人员健康情况列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:info:export")
    @SysLog(title = "人员健康情况", businessType = OperaType.EXPORT, logType = 1,module = "健康管理->导出人员健康情况")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonInfo healthPersonInfo) {
        List<HealthPersonInfo> list = healthPersonInfoService.selectHealthPersonInfoList(healthPersonInfo);
        ExcelUtil<HealthPersonInfo> util = new ExcelUtil<HealthPersonInfo>(HealthPersonInfo.class);
        util.exportExcel(response, list, "人员健康情况数据");
    }

    /**
     * 获取人员健康情况详细信息
     */
    @ApiOperation(value = "获取人员健康情况详细信息")
    //@RequiresPermissions("health:info:query")
    @PostMapping({"/detail-health-info"})
    public AjaxResult getInfo(@RequestBody HealthPersonInfo vo) {
        return success(healthPersonInfoService.selectHealthPersonInfoById(vo.getUserId()));
    }

    /**
     * 新增人员健康情况
     */
    @ApiOperation(value = "新增人员健康情况")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:info:add")
    @SysLog(title = "人员健康情况", businessType = OperaType.INSERT, logType = 1,module = "健康管理->新增人员健康情况")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonInfo healthPersonInfo) {
        try {
            return toAjax(healthPersonInfoService.insertHealthPersonInfo(healthPersonInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改人员健康情况
     */
    @ApiOperation(value = "修改人员健康情况")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:info:edit")
    @SysLog(title = "人员健康情况", businessType = OperaType.UPDATE, logType = 1,module = "健康管理->修改人员健康情况")
    @PostMapping({"/edit-health-info"})
    public AjaxResult edit(@RequestBody HealthPersonInfo healthPersonInfo) {
        try {
            return toAjax(healthPersonInfoService.updateHealthPersonInfo(healthPersonInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除人员健康情况
     */
    @ApiOperation(value = "删除人员健康情况")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:info:remove")
    @SysLog(title = "人员健康情况", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员健康情况")
    @PostMapping({"/del-health-info"})
    public AjaxResult remove(@RequestBody HealthPersonInfo healthPersonInfo) {
        return toAjax(healthPersonInfoService.deleteHealthPersonInfoById(healthPersonInfo));
    }
}
